## MeDIL
MeDIL is a Python package for causal inference, focusing on the Measurement Dependence Inducing Latent (MeDIL) Causal Model framework[<sup>1</sup>](#uai_paper).

More information can be found in the [documentation](https://medil.causal.dev) or on the [project web page](https://causal.dev/project/medil)

### Support, Bugs, and Contributing
If you have any questions, suggestions, feedback, or bugs to report, please [open an issue on Gitlab](https://gitlab.com/alex-markham/medil/issues/new) or [on Github](https://github.com/neuroinfo19/medil/issues/new) or [contact me](https://causal.dev/#contact).
Additionally, if you would like to use this package or any of its code in your research, or to contribute to this package, feel free (but not obliged) to [contact me](https://causal.dev/#contact).

### License
See [LICENSE](https://gitlab.com/alex-markham/medil/blob/master/LICENSE.txt), which is the Cooperative Non-Violent Public License v6 or later (CNPLv6+).

### Changelog
See [CHANGELOG](https://gitlab.com/alex-markham/medil/blob/master/CHANGELOG.md) for a history of the already implemented features, works in progress, and future feature ideas.

### References
<a name="uai_paper"> 1.</a> Markham, Alex & Grosse-Wentrup, Moritz. (2020). Measurement Dependence Inducing Latent Causal Models. In *Conference on Uncertainty in Artificial Intelligence (UAI)* PMLR 124:590&ndash;599. URL: [http://proceedings.mlr.press/v124/markham20a/markham20a.pdf](http://proceedings.mlr.press/v124/markham20a/markham20a.pdf)
